<?php

require_once 'Zend/Stdlib/autoload.php';
# The following are already included by Stdlib
# if (stream_resolve_include_path('Zend/EventManager/autoload.php')){
#     include_once 'Zend/EventManager/autoload.php';
# }
# if (stream_resolve_include_path('Zend/Serializer/autoload.php')){
#     include_once 'Zend/Serializer/autoload.php';
# }
# if (stream_resolve_include_path('Zend/ServiceManager/autoload.php')){
#     include_once 'Zend/ServiceManager/autoload.php';
# }
# if (stream_resolve_include_path('Zend/Filter/autoload.php')){
#     include_once 'Zend/Filter/autoload.php';
# }

// @codingStandardsIgnoreFile
// @codeCoverageIgnoreStart
// this is an autogenerated file - do not edit
spl_autoload_register(
    function($class) {
        static $classes = null;
        if ($classes === null) {
            $classes = array(
                ___CLASSLIST___
            );
        }
        $cn = strtolower($class);
        if (isset($classes[$cn])) {
            require ___BASEDIR___$classes[$cn];
        }
    }
);
// @codeCoverageIgnoreEnd
